changeset 733:2de8cf02af41 draft

Updated.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Fri, 12 Jun 2015 13:44:39 +0200
parents c043f06fd143
children d87d85bf1a4d
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 71 insertions(+), 66 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Thu Jun 11 14:18:29 2015 +0200
+++ b/ChangeLog	Fri Jun 12 13:44:39 2015 +0200
@@ -1,3 +1,8 @@
+2015-06-12  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated.
+
 2015-06-11  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Jun 11 14:18:29 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Fri Jun 12 13:44:39 2015 +0200
@@ -12700,13 +12700,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltGridBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -12715,13 +12715,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltGridBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -12730,13 +12730,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltGridBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -12745,13 +12745,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
+    public TestResult testBitBltGridBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -12760,13 +12760,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltGridBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -12775,13 +12775,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -12790,13 +12790,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -12805,13 +12805,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -12820,13 +12820,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -12835,9 +12835,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltDiagonalCheckerBufferedImageTypeByteGray(image, graphics2d, Color.red);
+    public TestResult testBitBltGridBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltGridBufferedImageTypeIntBGR(image, graphics2d, Color.red);
     }
 
     /**